@@ -29,14 +29,12 @@ from typing import Any, Coroutine, Dict, List, Union
 
 import socketio
 
-
 from .enums import AppID, Currency, Locale
 from .errors import ParamRequired
 from .http import HTTPClient
-from .item import Item, ItemWithSales, ItemOutOfStock
+from .item import Item, ItemOutOfStock, ItemWithSales
 from .iterators import TransactionAsyncIterator
-from .transaction import Credit, Withdraw, Purchase
-
+from .transaction import Credit, Purchase, Withdraw
 
 __all__ = ("Client",)
 
@@ -195,7 +193,12 @@ class Client:
                 self.ws.on("*", self.catch_all)
                 await self.ws.connect("https://skinport.com", transports=["websocket"])
                 await self.ws.emit(
-                    "saleFeedJoin", {"currency": currency.value, "locale": locale.value, "appid": app_id.value}
+                    "saleFeedJoin",
+                    {
+                        "currency": currency.value,
+                        "locale": locale.value,
+                        "appid": app_id.value,
+                    },
                 )
                 await self.ws.wait()
             except asyncio.TimeoutError:
